@echo off

rem ********************************************************************************
rem *
rem * CAPRAID.BAT
rem *
rem * This file captures the RAID configuration to a file.
rem *
rem ********************************************************************************


call loadraid.bat
%RAMDSK%

rem ********************************************************************************
rem * Set variables that control error conditions
rem ********************************************************************************
set E2_PARAM=
FOR %%i in (y Y) do if %RD_ERR2% == %%i set E2_PARAM=/e2

rem ********************************************************************************
rem * If Altiris, make a place to write the capture file
rem ********************************************************************************
if not %DPLY_TYPE%==4 goto CAPRAID

%TKDRV%
cd \
md %RD_PATH%
%RAMDSK%

:CAPRAID
rem ********************************************************************************
rem * Run PRAID to capture the RAID configuration to a file.
rem ********************************************************************************
PRAID /c /f:%RD_PATH%\%RD_FILE% %E2_PARAM%

if errorlevel 9 goto ERRMISC
if errorlevel 8 goto ERRGATH
if errorlevel 6 goto ERRTEMP
if errorlevel 5 goto ERRPOLY
if errorlevel 4 goto ERRCOMM
if errorlevel 3 goto ERRDRIVE
if errorlevel 2 goto ERRNRAID
if errorlevel 1 goto ERROR

call PRDERR.BAT

if %PRDERR% == 9 goto ERRMISC
if %PRDERR% == 8 goto ERRGATH
if %PRDERR% == 6 goto ERRTEMP
if %PRDERR% == 5 goto ERRPOLY
if %PRDERR% == 4 goto ERRCOMM
if %PRDERR% == 3 goto ERRDRIVE
if %PRDERR% == 2 goto ERRNRAID
if %PRDERR% == 1 goto ERROR

if %DPLY_TYPE%==4 goto ALTSTAT0
goto END


:ERRMISC
rem ********************************************************************************
rem * Error -- Miscellaneous error.
rem ********************************************************************************
set MSG=There was an error running the PRAID utility.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CAPRAID:  %MSG%"
goto ERROR


:ERRGATH
rem ********************************************************************************
rem * Error -- Could not gather information from the controller.
rem ********************************************************************************
set MSG=Could not gather RAID information from a supported controller.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CAPRAID:  %MSG%"
goto ERROR


:ERRTEMP
rem ********************************************************************************
rem * Error -- Could not write to temp space.
rem ********************************************************************************
set MSG=Could not write to temp space.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CAPRAID:  %MSG%"
goto ERROR


:ERRPOLY
rem ********************************************************************************
rem * Error -- policies file syntax error.
rem ********************************************************************************
set MSG=Policies file does not exist or syntax error in policies file.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CAPRAID:  %MSG%"
goto ERROR


:ERRCOMM
rem ********************************************************************************
rem * Error -- command line parameters incorrect.
rem ********************************************************************************
set MSG=Command-line syntax error calling PRAID.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CAPRAID:  %MSG%"
goto ERROR


:ERRDRIVE
rem ********************************************************************************
rem * Error -- no drives attached to one or more controllers
rem ********************************************************************************
set MSG=No drives attached to one or more controllers.
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CAPRAID:  %MSG%"
goto ERROR


:ERRNRAID
rem ********************************************************************************
rem * Error -- no RAID controllers found
rem ********************************************************************************
set MSG=Can not find a supported RAID controller to capture. 
echo %MSG%
echo.

if not %DPLY_TYPE%==4 goto ERROR
%TKDRV%\logevent.exe -c:2 -l:2 -ss:"CAPRAID:  %MSG%"
goto ERROR
    
             
:ERROR
rem ********************************************************************************
rem * Hit an error in this batch file.
rem ********************************************************************************
echo Encountered an error and stopped processing in "capraid.bat".

if %DPLY_TYPE%==4 goto ALTSTAT1

savestat.exe /set2=251 > nul

goto END


:ALTSTAT0
rem ********************************************************************************
rem * Update Altiris with necessary status
rem ********************************************************************************
echo Updating Altiris status: Good
%TKDRV%\logevent.exe -c:0 -l:1 -ss:"CAPRAID: Completed successfully."


rem Reset to root of Toolkit drive
%TKDRV%
cd \

goto END


:ALTSTAT1
rem ********************************************************************************
rem * Update Altiris with necessary status
rem ********************************************************************************
echo Updating Altiris status: Error
%TKDRV%\logevent.exe -c:251 -l:3 -ss:"CAPRAID:  Encountered an error."

rem Reset to root of Toolkit drive
%TKDRV%
cd \

rem Reset persistent storage
savestat.exe /reset > nul
goto END


:END
rem ********************************************************************************
rem * Finished.
rem ********************************************************************************
%TKDRV%

