@echo off

rem ********************************************************************************
rem *
rem * RUNINST.BAT
rem *
rem * This file controls the ServerGuide Scripting Toolkit Microsoft(R) Windows
rem * installation process.  Environment variables used here and in the batch files
rem * that are called by this file are defined in usrvars.bat.   When the processing of
rem * this file is complete, the target system will be updated, configured and
rem * installed with the requested operating system as specified in usrvars.bat.
rem *
rem * This batch file is called by the autoexec.bat.
rem *
rem * NOTE:  This batch files stores the number 251 to represent error conditions.
rem *
rem ********************************************************************************

rem ********************************************************************************
rem * Step 1:
rem *
rem * Setup any additional system variables to be used by the Toolkit process.
rem ********************************************************************************
call sysvars.bat

rem ********************************************************************************
rem * Check for errors from SYSVARS.BAT
rem ********************************************************************************
rem echo Checking for errors setting up additional system variables
savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SYSTEM-VARIABLES
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR


rem ********************************************************************************
rem * Step 2:
rem *
rem * Read persistent storage to determine which step in the Toolkit process to
rem * perform next.
rem *
rem * The information stored in persistent storage controls this Toolkit process.
rem ********************************************************************************
echo Checking persistent storage to determine which Toolkit process to perform.
savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem *
rem * The errorlevel here controls the installation process.
rem ********************************************************************************
if errorlevel 255 goto ERROR
if errorlevel 100 goto INST_OS
if errorlevel 75  goto PREPPART
if errorlevel 50  goto CFGFIBRE
if errorlevel 25  goto CFGRAID
if errorlevel 0   goto CKVARS


:CKVARS
rem ********************************************************************************
rem * Step 3:
rem *
rem * Need to verify that some important user's variables from usrvars.bat are good.
rem * If no problems, continue with the Toolkit process.
rem ********************************************************************************
call ckvars.bat

rem ********************************************************************************
rem * Check for errors from CKVARS.BAT
rem ********************************************************************************
rem echo Checking for errors from variable check.
savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: CHECK-VARIABLES
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR

rem echo Skipping ckvars step.

:RESET_PS
rem ********************************************************************************
rem * Step 4:
rem *
rem * Clear the rest of persistent storage to prevent any problems during the
rem * Toolkit process.
rem ********************************************************************************
savestat.exe /reset > nul


rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
if errorlevel 255 goto ERROR


:UPDATES
rem ********************************************************************************
rem * Step 5:
rem *
rem * Perform BIOS and firmware updates if selected.  DO_UPDS is defined and set
rem * in usrvars.bat.
rem ********************************************************************************
echo Checking if user has requested to perform updates: DO_UPDS = %DO_UPDS%
FOR %%i in (y Y) do if %DO_UPDS% == %%i goto RUN_UPD
goto CFGRAID


:RUN_UPD
echo Calling Updates batch file
call fwupdate.bat

rem ********************************************************************************
rem * Check for errors from UPDATES
rem ********************************************************************************
rem echo Checking for errors from updates
savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR


:CFGRAID
rem ********************************************************************************
rem * Step 6:
rem *
rem * Perform RAID configuration of any RAID adapters in the system, if selected.
rem * CFG_RAID is defined and set in usrvars.bat.
rem ********************************************************************************
echo Checking if user has requested to perform RAID configuration: CFG_RD = %CFG_RD%

FOR %%i in (y Y) do if %CFG_RD% == %%i goto RUNRAID
goto CFGFIBRE


:RUNRAID
echo Calling config RAID batch file

call cfgraid.bat

rem ********************************************************************************
rem * Check for errors from CFGRAID
rem ********************************************************************************
rem echo Checking for errors from RAID configuration

savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR


:CFGFIBRE
rem ********************************************************************************
rem * Step 7:
rem *
rem * Perform fibre host adapter configuration if the OS is to be installed to 
rem * a fibre host adapter.  DO_FIB is defined and set in usrvars.bat.
rem ********************************************************************************

rem Fibre configuration ONLY supported for Window installs
if %NOSDIR%==windows goto CK_FIB
goto PREPPART


:CK_FIB
echo Checking if user has requested to perform fibre configuration: DO_FIB = %DO_FIB%
FOR %%i in (y Y) do if %DO_FIB% == %%i goto RUN_FIB
goto PREPPART


:RUN_FIB
echo Calling fibre configuration batch file

call cfgfibre.bat

rem ********************************************************************************
rem * Check for errors from CFGFIBRE
rem ********************************************************************************
echo Checking for errors from fibre configuration

savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR


:PREPPART
rem ********************************************************************************
rem * Step 8:
rem *
rem * If a NOS specific file exists, prepare the first hard drive found in the
rem * system for the NOS partition.  This batch file will delete ALL partitions
rem * found on the first hard drive and create a new single primary NOS partition,
rem * whose size is defined (PARTITION_SIZE) and set in usrvars.bat.
rem ********************************************************************************
echo Checking for the existence of a partitioning batch file.
if exist %TK_PATH%\examples\%NOSDIR%\preppart.bat  goto RUN_PP
goto INST_OS


:RUN_PP
echo Calling partition preparation batch file
call %TK_PATH%\examples\%NOSDIR%\preppart.bat

rem ********************************************************************************
rem * Check for errors from PREPPART
rem ********************************************************************************
rem echo Checking for errors from preppart
savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR



:INST_OS
rem ********************************************************************************
rem * Step 9:
rem *
rem * Complete the Toolkit installation process.  This step calls an OS-type specific
rem * batch file, based on the NOSDIR variable set in usrvars.bat.   This batch
rem * file then performs the remaining steps required to complete the
rem * unattended installation of the requested operating system.
rem *
rem * The specific version of the operating system to be installed in defined and
rem * set in usrvars.bat
rem ********************************************************************************

rem ********************************************************************************
rem * NOTE:  This process may be running from removable media, such as a DOS-startable
rem * (bootable) CD-Rom.   Thus, the main installation batch file and specific helper
rem * files MUST be moved to the RAM drive to prevent runtime problems.
rem ********************************************************************************
copy %TK_PATH%\examples\%NOSDIR%\instos.bat %RAMDSK%\ > nul
copy %TK_PATH%\utils\reboot.com %RAMDSK%\ > nul
copy %TK_PATH%\utils\sleep.exe %RAMDSK%\ > nul

echo Calling main OS installation batch file
call %RAMDSK%\instos.bat

rem ********************************************************************************
rem * Check for errors from INST_OS
rem ********************************************************************************
savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR
goto END


:ERROR
rem ********************************************************************************
rem * Hit an error in this batch file.
rem ********************************************************************************
echo Encountered an error and stopped processing in "runinst.bat".

rem * Clear any error conditions.
savestat.exe /reset > nul

goto END



:END
